@@ -16,6 +16,7 @@ cnetplot.list <- function(
     size_edge = .5,
     node_label = "all",
     foldChange = NULL,
+    fc_threshold = NULL,
     hilight = "none",
     hilight_alpha = .3,
     ...
@@ -46,6 +47,17 @@ cnetplot.list <- function(
         node_label = "item"
     }
 
+    # Filter genes by absolute fold change threshold
+    if (!is.null(fc_threshold) && !is.null(foldChange)) {
+        keep_genes <- names(foldChange)[abs(foldChange) > fc_threshold]
+        foldChange <- foldChange[keep_genes]
+        x <- lapply(x, function(gs) {
+            intersect(gs, keep_genes)
+        })
+        # Remove empty sets
+        x <- x[sapply(x, length) > 0]
+    }
+
     g <- list2graph(x)
 
     V(g)$.hilight <- 1
